0.2.11 (2023-04-03)
-------------------

Documentation improvements

* #74 Added some documentation for django-admin commands and fixed ``s3_stale``
* Transferred some old documentation
* Fixed language in an image example
